@@ -10,7 +10,7 @@ from .converters import convert_to_boolean, convert_to_number
 from .errors import ContentNotFoundError
 from .formats import format_price
 from .govuk_frontend import get_href
-from .utils import TemplateField, drop_followups, get_option_value
+from .utils import TemplateField, drop_followups, drop_dependent_follow_ups, get_option_value
 
 TQuestion = TypeVar("TQuestion", bound="Question")
 TMultiquestion = TypeVar("TMultiquestion", bound="Multiquestion")
@@ -43,6 +43,9 @@ class Question(object):
         return all(
             depends["on"] in context and (context[depends["on"]] in depends["being"])
             for depends in self.get("depends", [])
+        ) and all(
+            question_id in context and (set(context[question_id]).intersection(set(question_values)))
+            for question_id, question_values in self.get("depends_on_follow_up", {}).items()
         )
 
     def get_question(self, field_name):
@@ -307,6 +310,7 @@ class Multiquestion(Question):
             questions_data.update(question.get_data(form_data))
 
         questions_data = drop_followups(self, questions_data)
+        questions_data = drop_dependent_follow_ups(self, questions_data)
 
         return questions_data
 
